IosPushPluginPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • IosPushPluginPlatform
Implementers

Constructors

IosPushPluginPlatform()
Constructs a IosPushPluginPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
onMessage Stream
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

enableLog(bool enable) → void
getManufacturer() Future<String?>
getPlatformVersion() Future<String?>
initPush() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register() Future
requestPermission() Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance IosPushPluginPlatform
The default instance of IosPushPluginPlatform to use.
getter/setter pair